Macro to сheck that the user has all the specified permissions.
Allow to add a conditional restriction based on handlers parameters.
Add the secure attribute followed by the the boolean expression to validate based on parameters
Macro for poem-openapi support
Add macro #[poem_grants::open_api] above of #[poem_openapi::OpenApi] and mark all needed methods with necessary security-methods:
One of [has_permissions, has_any_permission, has_roles, has_any_role]